@@ -2,5 +2,6 @@ from .services import (
     batch,
     ecs,
     rds,
-    s3
+    s3,
+    sqs
 )
\ No newline at end of file
