@@ -140,6 +140,14 @@ class RDSClient():
         query = f'INSERT INTO neuralplatform_page(imgUri, ocrUri, document_id) VALUES ("{img_uri}", "{ocr_uri}", {document_id});'
         return self.insert_query(query)
     
+    def update_page_img(self,
+                        page_id: int,
+                        img_uri: str) -> int:
+        """
+        """
+        query = f'UPDATE neuralplatform_page SET imgUri = "{img_uri}" WHERE id = {page_id};'
+        return self.insert_query(query)
+    
     def update_page_ocr(self,
                         page_id: int,
                         ocr_uri: str) -> int:
@@ -182,3 +190,20 @@ class RDSClient():
         """
         query = f"SELECT COUNT(*) AS count FROM neuralplatform_classdefinition WHERE project_id = {project_id};"
         return self.select_query(query, fetchone=True)['count']
+
+    def insert_model(self,
+                     version_id: int,
+                     model_name: str,
+                     hyperparams: str,
+                     results_file_uri: str) -> int:
+        """
+        """
+        query = f"INSERT INTO neuralplatform_model(name, hyperparams, resultsFileUri, version_id) VALUES('{model_name}', '{hyperparams}', '{results_file_uri}', {version_id});"
+        return self.insert_query(query)
+    
+    def get_version_model(self,
+                  version_id: int) -> dict:
+        """
+        """
+        query = f"SELECT * FROM neuralplatform_model WHERE version_id = {version_id};"
+        return self.select_query(query, fetchone=True)
