@@ -17,10 +17,11 @@ class S3Client(Boto3Client):
                      project_name: str,
                      version_id: int,
                      model_name: str,
-                     filepath: str):
+                     filepath: str,
+                     filename: str = 'model.h5'):
         """
         """
-        file_path = f"{project_name}/versions/{version_id}/models/{model_name}/model.pb"
+        file_path = f"{project_name}/versions/{version_id}/models/{model_name}/{filename}"
         self.upload_file(filepath, Bucket=bucket, Key=file_path)
         
     def download_model(self,
@@ -28,12 +29,12 @@ class S3Client(Boto3Client):
                        project_name: str,
                        version_id: int,
                        model_name: str,
-                       filepath: str = 'model.pb') -> str:
+                       filename: str = 'model.h5') -> str:
         """
         """
-        file_path = f"{project_name}/versions/{version_id}/models/{model_name}/model.pb"
-        self.download_file(bucket, file_path, filepath)
-        return filepath
+        file_path = f"{project_name}/versions/{version_id}/models/{model_name}/{filename}"
+        self.download_file(bucket, file_path, filename)
+        return filename
     
     def upload_model_parameters(self,
                                 bucket: str,
@@ -58,6 +59,30 @@ class S3Client(Boto3Client):
         parameters = json.load(open('tmp.json', 'r'))
         os.remove('tmp.json')
         return parameters
+    
+    def upload_model_evaluation(self,
+                                bucket: str,
+                                project_name: int,
+                                version_id: int,
+                                model_name: str,
+                                evaluation: dict):
+        """
+        """
+        file_path = f"{project_name}/versions/{version_id}/models/{model_name}/evaluation/evaluation.json"
+        self.put_object(Body=json.dumps(evaluation).encode(), Bucket=bucket, Key=file_path)
+    
+    def get_model_evaluation(self,
+                             bucket: str,
+                             project_name: int,
+                             version_id: int,
+                             model_name: str):
+        """
+        """
+        file_path = f"{project_name}/versions/{version_id}/models/{model_name}/evaluation/evaluation.json"
+        self.download_file(bucket, file_path, 'tmp.json')
+        evaluation = json.load(open('tmp.json', 'r'))
+        os.remove('tmp.json')
+        return evaluation
         
     def get_vocab(self,
                   bucket: str,
@@ -90,17 +115,6 @@ class S3Client(Boto3Client):
         """
         """
         self.put_object(Body=json.dumps(word2idx).encode(), Bucket=bucket, Key=f"{project_name}/config/word2idx.json")
-    
-    def upload_model(self,
-                     bucket: str,
-                     project_name: str,
-                     version_id: int,
-                     model_name: int,
-                     model_path: str):
-        """
-        """
-        extension = model_path.split('.')[-1]
-        self.upload_file(model_path, bucket, f"{project_name}/versions/{version_id}/models/{model_name}/model.{extension}")
 
     def get_project_classes(self,
                             bucket: str,
